@@ -640,7 +640,7 @@ class HildonGui(HildonToolsDialog, HildonSearchPlace, HildonFieldnotes, HildonSe
         self.core.save_settings(update, self)
     
     def _show_default_log_text_settings(self, widget, data):
-        dialog = gtk.Dialog("Default Fieldnote Text", None, gtk.DIALOG_DESTROY_WITH_PARENT, (gtk.STOCK_OK, gtk.RESPONSE_ACCEPT))
+        dialog = gtk.Dialog("Default Log/Fieldnote Text", None, gtk.DIALOG_DESTROY_WITH_PARENT, (gtk.STOCK_OK, gtk.RESPONSE_ACCEPT))
         default_log_text = hildon.TextView()
         default_log_text.get_buffer().set_text(self.settings['options_default_log_text'])
         dialog.vbox.pack_start(default_log_text)
@@ -799,7 +799,7 @@ class HildonGui(HildonToolsDialog, HildonSearchPlace, HildonFieldnotes, HildonSe
             first_log = 10 + tab_number*logs_in_page #10=number of logs shown in basic view
             last_log = first_log + logs_in_page
             if last_log >= len(logs):
-               last_log = len(logs)
+                last_log = len(logs)
             label = str(first_log+1) +"-"+ str(last_log) #add 1 to showing first log, so they are more human readable
             notebook.append_page(page, gtk.Label(label))
 
@@ -843,7 +843,7 @@ class HildonGui(HildonToolsDialog, HildonSearchPlace, HildonFieldnotes, HildonSe
         attribute_table = gtk.HBox()
 
         if cache.attributes != None:
-            for attribute in cache.attributes.split(',')[0:-1]:
+            for attribute in cache.attributes.split(','):
                 filename = join(self.settings['download_output_dir'], attribute)
                 attribute_table.pack_start(gtk.image_new_from_file(filename))
         else:
@@ -923,19 +923,19 @@ class HildonGui(HildonToolsDialog, HildonSearchPlace, HildonFieldnotes, HildonSe
 
                 text_shortdesc_esc = my_gtk_label_escape(self._strip_html(cache.shortdesc).strip())
                 text_longdesc_esc = my_gtk_label_escape(self._strip_html(text_longdesc).strip())
-                
+                #logger.debug("Short description is '%s'" % cache.shortdesc)
+                #logger.debug("Long description is '%s'" % text_longdesc)
+
+                #if short and long -descriptions are empty, use 'No description available'
+                if text_shortdesc_esc == '' and text_longdesc_esc == '':
+                    text_shortdesc_esc = "<i>No description available</i>"
+
+                #If cache is disabled, add warning
                 if cache.status == geocaching.GeocacheCoordinate.STATUS_DISABLED:
-                    text_shortdesc = '<u>This Cache is not available!</u>\n%s' % text_shortdesc
+                    text_shortdesc_esc = '<u>This Cache is not available!</u>\n%s' % text_shortdesc_esc
+
+                showdesc = "<b>%s</b>\n\n%s" % (text_shortdesc_esc, text_longdesc_esc)
 
-                if text_longdesc != '' and text_shortdesc != '':
-                    showdesc = "<b>%s</b>\n\n%s" % (text_shortdesc_esc, text_longdesc_esc)
-                elif text_longdesc == '' and text_shortdesc == '':
-                    showdesc = "<i>No description available</i>"
-                elif text_longdesc == '':
-                    showdesc = text_shortdesc_esc
-                else:
-                    showdesc = text_longdesc_esc
-                    
                 widget_description.set_markup(showdesc)
                 events.append(self.window.connect('configure-event', self._on_configure_label, widget_description))
                 
@@ -1140,9 +1140,10 @@ class HildonGui(HildonToolsDialog, HildonSearchPlace, HildonFieldnotes, HildonSe
             container = gtk.VBox()
             for l in logs:
                 try:
-                    w_type = gtk.image_new_from_pixbuf(self.icon_pixbufs[l['type']])
+                    filename = join(self.settings['download_output_dir'], l['typeicon'])  # typeicon is like "1.png"
+                    w_type = gtk.image_new_from_file(filename)
                 except KeyError:
-                    w_type = gtk.Label(l['type'].upper())
+                    w_type = gtk.Label(l['type'].upper())   # type is like "found it"
                     w_type.set_alignment(0, 0)
                 w_finder = gtk.Label()
                 w_finder.set_markup(" <b>%s</b>" % my_gtk_label_escape(HTMLManipulations._decode_htmlentities(l['finder'])))
@@ -1159,12 +1160,12 @@ class HildonGui(HildonToolsDialog, HildonSearchPlace, HildonFieldnotes, HildonSe
                 w_text.set_alignment(0, 0)
 
                 if events != None:
-                   events.append(self.window.connect('configure-event', self._on_configure_label, w_text, True))
+                    events.append(self.window.connect('configure-event', self._on_configure_label, w_text, True))
 
                 if dialog: #inside dialog (not window)
-                   w_text.set_size_request(self.window.size_request()[0] - 60, -1)
+                    w_text.set_size_request(self.window.size_request()[0] - 60, -1)
                 else:
-                   w_text.set_size_request(self.window.size_request()[0] - 10, -1)
+                    w_text.set_size_request(self.window.size_request()[0] - 10, -1)
 
                 w_first = gtk.HBox()
                 w_first.pack_start(w_type, False, False)
